

/*
 ## Cypress FX3 Core Library Header (cyu3imagesensor.h)
 ## ===========================
 ##
 ##  Copyright Cypress Semiconductor Corporation, 2010-2014,
 ##  All Rights Reserved
 ##  UNPUBLISHED, LICENSED SOFTWARE.
 ##
 ##  CONFIDENTIAL AND PROPRIETARY INFORMATION
 ##  WHICH IS THE PROPERTY OF CYPRESS.
 ##
 ##  Use of this file is governed
 ##  by the license agreement included in the file
 ##
 ##     <install>/license/license.txt
 ##
 ##  where <install> is the Cypress software
 ##  installation root directory path.
 ##
 ## ===========================
 */

/* CX3 Header file for APIs implementing Image Sensor specific functions
 */

// Enumeration defining Stream Format used for CyCx3_ImageSensor_Set_Format

/* Initialize Image Sensor*/ 
CyU3PReturnStatus_t CyCx3_ImageSensor_Init();


					
/* Set Sensor to output 5M Stream */
CyU3PReturnStatus_t CyCx3_ImageSensor_Set_5M ();
/* Set Sensor to output 1080p Stream */
CyU3PReturnStatus_t CyCx3_ImageSensor_Set_1080p ();
/* Set Sensor to output 720p Stream */
CyU3PReturnStatus_t CyCx3_ImageSensor_Set_720p ();
/* Set Sensor to output Vga Stream */
CyU3PReturnStatus_t CyCx3_ImageSensor_Set_Vga ();

/* Put Image Sensor to Sleep/Low Power Mode */
CyU3PReturnStatus_t CyCx3_ImageSensor_Sleep();

/* Wake Image Sensor from Sleep/Low Power Mode to Active Mode */
CyU3PReturnStatus_t CyCx3_ImageSensor_Wakeup();

/* Set Image Sensor Data Format */
CyU3PReturnStatus_t CyCx3_ImageSensor_Set_Format(CyU3PSensorStreamFormat_t format);

/* Trigger Autofocus for the Sensor*/
CyU3PReturnStatus_t CyCx3_ImageSensor_Trigger_Autofocus();


void gpioinit( void );		//	setup I/Os for our dual-camera board


/*
 * from https://github.com/6by9/raspiraw/blob/master/ov5647_modes.h
 *
 *  Created on: Nov 26, 2018
 *      Author: User
 */


/*
Copyright (c) 2015-2017, Raspberry Pi Foundation
Copyright (c) 2015, Dave Stevenson
All rights reserved.
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the copyright holder nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


// These register settings were as logged off the line
// by jbeale. There is a datasheet for OV5647 floating
// about on the internet, but the Pi Foundation/Trading have
// information from Omnivision under NDA, therefore
// we can not offer support on this.
// There is some information/discussion on the Freescale
// i.MX6 forums about supporting OV5647 on that board.
// There may be information available there that is of use.
//
// REQUESTS FOR SUPPORT ABOUT THESE REGISTER VALUES WILL
// BE IGNORED.

#if	0
Some tables from this module found on the internet.

MODULE_AUTHOR("raymonxiu");
MODULE_DESCRIPTION("A low-level driver for OV5647 sensors");
MODULE_LICENSE("GPL");
#endif

#define OV5640_DEBUG

#define NUM_ELEMENTS(a)  (sizeof(a) / sizeof(a[0]))

#define OV5647_I2C_ADRESS               (0x6C>>1)
#define OV5647_I2C_READ_ADDRESS         ((OV5647_I2C_ADRESS << 1) | 1)
#define OV5647_I2C_WRITE_ADDRESS        ((OV5647_I2C_ADRESS << 1))
#define OV5647_CHIP_ID                  (0x5647)
#define OV5647_CHIP_ID_HIGH_BYTE        (0x300A)
#define OV5647_CHIP_ID_LOW_BYTE         (0x300B)
#define	REG_DLY							(0xFFFF)				//	embed in sensor_regs_t to generate a delay


typedef enum bayer_order {
	//Carefully ordered so that an hflip is ^1,
	//and a vflip is ^2.
	BAYER_ORDER_BGGR,
	BAYER_ORDER_GBRG,
	BAYER_ORDER_GRBG,
	BAYER_ORDER_RGGB
} bayer_order_t;

typedef struct sensor_regs
{
	uint16_t reg;
	uint16_t data;
} sensor_regs_t;

typedef struct mode_def
{
	struct sensor_regs *regs;
	int num_regs;
	int width;
	int height;
//	MMAL_FOURCC_T encoding;
	enum bayer_order order;
	int native_bit_depth;
	uint8_t image_id;
	uint8_t data_lanes;
	int min_vts;
	int line_time_ns;
	uint32_t timing[5];
	uint32_t term[2];
	int black_level;
} mode_def_t;

typedef struct sensor_def
{
	char *name;
	struct mode_def *modes;
	int num_modes;
	struct sensor_regs *stop;
	int num_stop_regs;

	uint8_t i2c_addr;		// Device I2C slave address
	int i2c_addressing;		// Length of register address values
	int i2c_data_size;		// Length of register data to write

	//  Detecting the device
	int i2c_ident_length;		// Length of I2C ID register
	uint16_t i2c_ident_reg;		// ID register address
	uint16_t i2c_ident_value;	// ID register value

	// Flip configuration
	uint16_t vflip_reg;		// Register for VFlip
	int vflip_reg_bit;		// Bit in that register for VFlip
	uint16_t hflip_reg;		// Register for HFlip
	int hflip_reg_bit;		// Bit in that register for HFlip
	int flips_dont_change_bayer_order;	// Some sensors do not change the
						// Bayer order by adjusting X/Y starts
						// to compensate.

	uint16_t exposure_reg;
	int exposure_reg_num_bits;

	uint16_t vts_reg;
	int vts_reg_num_bits;

	uint16_t gain_reg;
	int gain_reg_num_bits;
} sensor_def_t;


int8_t getbrightness(uint8_t option);
void setbrightness( uint8_t value );
CyU3PReturnStatus_t initio( int ionum, int isout, int istate );
void gpioinit( void );

void dump( void *p, int size );


//	1/2/2019	more compatible camera control functions

uint8_t	camres;

CyU3PReturnStatus_t resetcameraresolution( void );
CyU3PReturnStatus_t setcameraresolution( uint8_t resolution );
uint16_t getcontrast( uint8_t option );
CyU3PReturnStatus_t setcontrast( uint16_t contrast );
uint32_t getexposure( uint8_t option );
CyU3PReturnStatus_t setexposure( uint32_t exposure );
uint8_t getautoexposure( uint8_t option );
CyU3PReturnStatus_t setautoexposure( uint32_t autoexposure );
uint32_t gethue( uint8_t option );
CyU3PReturnStatus_t sethue( uint32_t hue );
uint16_t getmanualfocus( uint8_t option );
CyU3PReturnStatus_t setmanualfocus( uint16_t manualfocus );
uint16_t getsaturation( uint8_t option );
CyU3PReturnStatus_t setsaturation( uint8_t saturation );
uint16_t getsharpness( uint8_t option );
CyU3PReturnStatus_t setsharpness( uint8_t sharpness );
uint8_t getautofocus( uint8_t option );
CyU3PReturnStatus_t setautofocus( uint8_t autofocus );
uint16_t getwhitebalance( uint8_t option );
CyU3PReturnStatus_t setwhitebalance( uint8_t whitebalance );

