/*
 * sysconfig.h
 *
 *  Created on: Jan 23, 2019
 *      Author: Scott Grodevant
 *
 *  System configuration settings
 *
 */

#ifndef SYSCONFIG_H_
#define SYSCONFIG_H_

//	Default resolution

//#define	M5
#define	P1080
//#define	P720
//#define	VGA


//	OV5647_6by9

#define	ORGVGA																	//	to use the original 6x9 table, else https://patchwork.kernel.org/patch/9605729/
#define	SIXBYNINE																//	to use the 6by9 tables, else use Ray Monxiu tables, where available
#define	V4L2																	//	Use settings from the V4L2 driver (where available)
#define	OV5640_DEBUG															//	enable debug code
#define	TESTPATTERN	( 0 )														//	0x503D register value.  0-normal, 0b10000100 = vertical bars
#define	R3034		( 0x1a )													//	0x1a for 10-bit data, else 0x18 for 8-bit


//	cyu3mipicsi

//#define	MIPIFORMAT	( CY_U3P_CSI_DF_RAW8 )										//	see typedef enum CyU3PMipicsiDataFormat_t in cyu3mipicsi.h for possible values
#define	MIPIFORMAT	( CY_U3P_CSI_DF_RAW10 )


//	cycx3_uvc

#define	GPIF_BUS_WIDTH ( CY_U3P_MIPICSI_BUS_16 )								//	see typedef enum CyU3PMipicsiBusWidth_t in cyu3mipicsi.h

//	cycx3_uvcdscr

//	Resolution Widths

#define	W5M		( 2592L )
#define	W1080p	( 1920L )
#define	W720p	( 1280L )
#define	WVGA	( 640L )

//	Resolution Heights

#define	H5M		( 1944L )
#define	H1080p	( 1080L )
#define	H720p	( 720L )
#define	HVGA	( 480L )


#define	FR5M	( 15 )															//	5M frame rate
#define	FR1080p	( 30 )															//	1080p "
#define	FR720p	( 30 )	//	don't set this to 60 even though it is 60 fps!		//	720p  "
#define	FRVGA	( 60 )															//	VGA   "

#define	BPP		( 16 )															//	bits per pixel, in USB descriptor
#define	BPPC	( 16 )															//	for descriptor calculations

//	Bit rates

#define	BR5M	( FR5M * W5M * H5M * BPPC )										//	5M bit rate
#define	BR1080p	( FR1080p * W1080p * H1080p * BPPC )							//	1080p	 "
#define	BR720p	( FR720p * W720p * H720p * BPPC )								//	720p	 "
#define	BRVGA	( FRVGA * WVGA * HVGA * BPPC )									//	VGA		 "

//	Frame sizes

#define	FS5M	( W5M * H5M * BPPC / 8 )										//	5M frame size, bytes
#define	FS1080p	( W1080p * H1080p * BPPC / 8 )									//	1080p	"
#define	FS720p	( W720p * H720p * BPPC / 8 )									//	720p	"
#define	FSVGA	( WVGA * HVGA * BPPC / 8 )										//	VGA		"

//	Frame intervals

#define	FI5M	( 10000000L / FR5M )											//	frame interval 5M (in 100 ns units)
#define	FI1080p	( 10000000L / FR1080p )											//	1080p 	"
#define	FI720p	( 10000000L / FR720p )											//	720p	"
#define	FIVGA	( 10000000L / FRVGA )											//	VGA		"


//	Macros to separate the individual bytes of a 32-bit value

#define	B0( v ) ( ( (unsigned long) v >> 24 ) & 0xFF )							//	get LSB written last
#define	B1( v ) ( ( (unsigned long) v >> 16 ) & 0xFF )
#define	B2( v )	( ( (unsigned long) v >>  8 ) & 0xFF )
#define	B3( v ) ( ( (unsigned long) v >>  0 ) & 0xFF )							//	get MSB

//	Define one of these:

//#define	RGB565
#define	YUY2

//	The ACTIVE GUID
    /* GUID, globally unique identifier used to identify streaming-encoding format*/
    //	YUY2: 32595559-0000-0010-8000-00AA00389B71
    //	0x59, 0x55, 0x59, 0x32, 0,       0, 0x10, 0x00, 0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71,
    //	MEDIASUBTYPE_RGB565 	e436eb7b-524f-11ce-9f53-0020af0ba770


//	RGB565
#ifdef	RGB565
#define	G0	( 0x7b )
#define	G1	( 0xeb )
#define	G2	( 0x36 )
#define	G3	( 0xe4 )
#define	G4	( 0x4f )
#define	G5	( 0x52 )
#define	G6	( 0xce )
#define	G7	( 0x11 )
#define	G8	( 0x9f )
#define	G9	( 0x53 )
#define	G10	( 0x00 )
#define	G11	( 0x20 )
#define	G12	( 0xaf )
#define	G13	( 0x0b )
#define	G14	( 0xa7 )
#define	G15	( 0x70 )
#endif
#ifdef YUY2
#define	G0	( 0x59 )
#define	G1	( 0x55 )
#define	G2	( 0x59 )
#define	G3	( 0x32 )
#define	G4	( 0x00 )
#define	G5	( 0x00 )
#define	G6	( 0x10 )
#define	G7	( 0x00 )
#define	G8	( 0x80 )
#define	G9	( 0x00 )
#define	G10	( 0x00 )
#define	G11	( 0xaa )
#define	G12	( 0x00 )
#define	G13	( 0x38 )
#define	G14	( 0x9b )
#define	G15	( 0x71 )
#endif




#endif /* SYSCONFIG_H_ */
