/*
	Projector control routines
	2/22/2019 Scott Grodevant for Optel, Inc.

	control of AK-02-00277_B

	Signals:

	GPIO#	Signal		Use
	47		CX3CS		Active low enables projector's on-board SST25VF016B serial Flash
						PROJ_ON must be false to disable the DLPC3470 (e.g. prevent it from accessing Flash)
	19		PROJ_ON		Enables projector
	20		PROJ_IRQ	Projector interrupt (active high)
	21		TRIG2		From DLPC3470 GPIO7
	45		PATRDY		DLPC pattern ready (pattern data is loaded from Flash)
	25		FPIO4		DLPC 3DR (rising edge triggers next pattern display)

	The SPI interface in conjunction with -CX3CS
 */


#define	AP		( 0x36 )														//	projector I2C address, or 0x3A
//#define REVE																	//	enable PCB REV E signal defs
#define	REVD																	//	enable PCB REV D signal defs

#define	FPIO0	( 17 )															//	GPIO17 is FPIO0
#define	FPIO1	( 18 )															//	GPIO18 is FPIO0
#define	PROJON	( 19 )															//	GPIO19 is projector on
#define	PROJIRQ	( 20 )															//	GPIO20 is -PROJ_IRQ
#define	TRIG2	( 21 )															//	GPIO21 is TRIG2
#define	FPIO2	( 22 )															//	GPIO22 is FPIO2
#define	FPIO3	( 23 )															//	GPIO23 is FPIO3
#define	CAMON	( 24 )															//	GPIO24 is CAMON
#define	CAMSEL	( 26 )															//	GPIO26 is CAM1 select mux
#define	CAMIO1	( 44 )															//	GPIO44 is CAMIO1 (unused)


#ifdef	REVE
#define	FPIO4	( 25 )															//	GPIO25 is FPIO4
#define	PATRDY	( 45 )															//	GPIO45 is FPIO5/pattern ready
#define	FLASHOE	( 47 )															//	GPIO47 is -FLASHOE (low to enable projector flash access)
#define	CX3CS	( 54 )															//	GPIO54 is projector flash access enable
#endif

#ifdef	REVD
#define	FPIO4	( 25 )															//	GPIO25 is FPIO4
#define	FPIO5	( 45 )															//	GPIO45 is FPIO5 (no pattern ready from projector yet)
#define	CX3CS	( 54 )															//	GPIO54 is the CX3's onboard Flash -CS
#endif

#ifdef	REVA
#define	BLUE1	( 25 )															//	GPIO25 is blue LED 1
#define	RED1	( 45 )															//	GPIO45 is red LED 1
#define	GREEN1	( 53 )															//	GPIO53 is green LED 1
#define	GREEN2	( 54 )															//	GPIO54 is green LED 2
#define	RED2	( 55 )															//	GPIO55 is red LED 2
#define	BLUE2	( 56 )															//	GPIO56 is blue LED 2
#endif



typedef enum
{
	bar_none,
	bar_solid,
	bar_hramp,
	bar_vramp,
	bar_horiz,
	bar_diag,
	bar_vert,
	bar_grid,
	bar_checkerboard,
	bar_vertcolor
} bar_types;

extern bar_types	testpat;													//	current test pattern

bool	projectorinit( void );													//	initialize the projector interface

bool	writeflash( int screen, int addr, int bytes, byte *data );				//	load projector flash

bool	readflash( int screen, int addr, int bytes, byte *data );				//	retrieve flash data

bool	setscreen( int screen );												//	prepare to show a splash screen image

bool	nextscreen( void );														//	show the next screen

bool	setbars( bar_types type, int on, int off );								//	display a bar test pattern, vertical|!horizontal, bar width, foreground & background colors

