/*
	Implement a UART between a host PC application and firmware via USB and vendor commands.
	devin and devout defined in _uvc.h allow sending data between device and host (PC).

	The devout sends data from the device to the PC, and devin sends data from the PC to the dev.
	The roles are reversed on the PC end.

*/

#include "cyu3system.h"
#include "cyu3os.h"
#include "cyu3error.h"
#include "cyu3usb.h"
#include "cyu3utils.h"
#include "cyu3pib.h"

#include "sysconfig.h"
#include "usbuart.h"


byte	rfifo[ FIOSIZE ];														//	receive FIFO
byte	xfifo[ FIOSIZE ];														//	transmit FIFO
byte	*riptr = rfifo, *roptr = rfifo;											//	rx in and out pointers
byte	*xiptr = xfifo, *xoptr = xfifo;											//	tx in and out ptrs


//	Returns true if the PC has sent us unprocessed data.

bool charin( void )
{
	return( !( riptr == roptr ) );												//	if we have unprocessed data
}


//	Retrieve the oldest unprocessed character from the PC.  If there are no
//	received characters, wait for some.

byte getbyte( void )
{
	byte	rls;

	if ( charin() )
	{
getit:
		rls = *riptr ++;
		if ( riptr >= rfifo + sizeof( rfifo ) )
			riptr = rfifo;

		return( rls );
	}
	else
	{
		while ( !charin() ) ;
		goto getit;
	}
}


//	Put a received host char in the FIFO.

void stash( byte b )
{
	*roptr ++ = b;
	if ( roptr >= rfifo + sizeof( rfifo ) )
		roptr = rfifo;
}


//	Send a single char to the PC

void putbyte( byte b )															//	send a character to the PC
{
	*xiptr ++ = b;																//	save char in output buffer
	if ( xiptr >= xfifo + sizeof( xfifo ) ) xiptr = xfifo;						//	wrap around
	while ( xoptr == xiptr ) ;													//	if the buffer fills, wait
}

//	Send string to PC

void outs( byte *buf )															//	send a string to the PC
{
	while ( strlen( (char *) buf ) )
	{
		putbyte( *buf ++ );
	}
}


byte charout( void )
{
	int		cnt = xiptr - xoptr;

	if ( cnt < 0 ) cnt += sizeof( xfifo );										//	if ptrs are swapped
	return( (byte) cnt );														//	count of chars in xfifo
}


byte getout( void )
{
	byte	rls;

	if ( charout() )
	{
getnext:
		rls = *xoptr ++;
		if ( xoptr >= xfifo + sizeof( xfifo ) ) xoptr = xfifo;
		return( rls );
	}
	else
	{
		while ( !charout() ) ;
		goto getnext;
	}
}
